<?php
/*
Plugin Name: Extend Visual Composer Plugin Example
Plugin URI: http://wpbakery.com/vc
Description: Extend Visual Composer with your own set of shortcodes.
Version: 0.1.1
Author: WPBakery
Author URI: http://wpbakery.com
License: GPLv2 or later
*/

/*
This example/starter plugin can be used to speed up Visual Composer plugins creation process.
More information can be found here: http://kb.wpbakery.com/index.php?title=Category:Visual_Composer
*/

// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

class SCP_Embellishment {

	protected $shortcode_name = 'scp_embellishment';
	protected $title = 'Embellishment';
	protected $description = '';
	protected $textdomain = 'care';

	function __construct() {
		// We safely integrate with VC with this hook
		add_action( 'init', array( $this, 'integrateWithVC' ) );

		// Use this when creating a shortcode addon
		add_shortcode( $this->shortcode_name, array( $this, 'render' ) );

		// Register CSS and JS
//		add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
	}

	public function integrateWithVC() {
		// Check if Visual Composer is installed
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			// Display notice that Visual Compser is required
			add_action( 'admin_notices', array( $this, 'showVcVersionNotice' ) );

			return;
		}

		/*
		Add your Visual Composer logic here.
		Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

		More info: http://kb.wpbakery.com/index.php?title=Vc_map
		*/
		vc_map( array(
			"name"        => __( $this->title, 'airpro' ),
			"description" => __( $this->description, 'airpro' ),
			"base"        => $this->shortcode_name,
			"class"       => "",
			"controls"    => "full",
			"icon"        => plugins_url( 'assets/creatopus-vc-icon.png', __FILE__ ),
			// or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
			"category"    => __( 'Creatopus', 'js_composer' ),
			//'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
			//'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
			"params"      => array(
				array(
					'type'        => 'colorpicker',
					'heading'     => __( 'Color', 'airpro' ),
					'param_name'  => 'color',
					'description' => __( 'If color is not set, theme accent color will be used.', 'airpro' ),
				),
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Extra class name', 'airpro' ),
					'param_name'  => 'el_class',
					'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'airpro' ),
				),
			)
		) );
	}

	/*
	Shortcode logic how it should be rendered
	*/
	public function render( $atts, $content = null ) {

		extract( shortcode_atts( array(
			'color'    => '',
			'el_class' => '',
		), $atts ) );

		$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $el_class, $this->shortcode_name, $atts );

		$accent_color = airpro_get_option( 'global-accent-color', '#000' );

		if ( ! $color ) {
			$color = $accent_color;
		}

		$uid = uniqid('embellishment-');

		$out = '';
		$out .= '<div';
		$out .= ' class="' . $css_class . '"';
		$out .= ' style="width: 96px;margin: 0 auto;">';
		$out .= '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 96 24">';
		$out .= '<style type="text/css">';
		$out .= '.' . $uid . '{';
		$out .= 'fill-rule:evenodd;';
		$out .= 'clip-rule:evenodd;';
		$out .= 'fill: ' . $color . ';';
		$out .= '}';
		$out .= '</style>';
		$out .= '<path class="' . $uid . '" d="M48 0H0c0 0 14.4 0.4 19 5 5.5 5.5 15.8 18.8 29 19 13.2-0.2 23.5-13.5 29-19 4.6-4.6 19-5 19-5H48z"/>';
		$out .= '</svg>';
		$out .= '</div>';

		return $out;
	}

	/*
	Load plugin css and javascript files which you may need on front end of your site
	*/
	public function loadCssAndJs() {
//		wp_register_style( 'vc_extend_style', plugins_url( 'assets/vc_extend.css', __FILE__ ) );
//		wp_enqueue_style( 'vc_extend_style' );

		// If you need any javascript files on front end, here is how you can load them.
		//wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery') );
	}

	/*
	Show notice if your plugin is activated but Visual Composer is not
	*/
	public function showVcVersionNotice() {
		$plugin_data = get_plugin_data( __FILE__ );
		echo '
        <div class="updated">
          <p>' . sprintf( __( '<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'airpro' ), $plugin_data['Name'] ) . '</p>
        </div>';
	}
}

// Finally initialize code
new SCP_Embellishment();
