<?php
// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

class Scp_Theme_Icon {

	protected $name = 'Theme Icon';
	protected $namespace = 'scp_theme_icon';
	protected $textdomain = SCP_TEXT_DOMAIN;

	function __construct() {
		// We safely integrate with VC with this hook
		add_action( 'init', array( $this, 'integrateWithVC' ) );

		// Use this when creating a shortcode addon
		add_shortcode( $this->namespace, array( $this, 'render' ) );

		// Register CSS and JS
		add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'loadCssAndJs' ) );

		add_filter( 'vc_iconpicker-type-theme-icons', array( $this, 'theme_icons' ) );
	}

	public function integrateWithVC() {
		// Check if Visual Composer is installed
		if ( ! defined( 'WPB_VC_VERSION' ) ) {
			// Display notice that Visual Compser is required
			add_action( 'admin_notices', array( $this, 'showVcVersionNotice' ) );

			return;
		}

		/*
		Add your Visual Composer logic here.
		Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.

		More info: http://kb.wpbakery.com/index.php?title=Vc_map
		*/
		vc_map( array(
			'name'             => esc_html( $this->name, 'airpro' ),
			'description'      => '',
			'base'             => $this->namespace,
			'class'            => '',
			'controls'         => 'full',
			'icon'             => plugins_url( 'assets/creatopus-vc-icon.png', __FILE__ ),
			// or css class name which you can reffer in your css file later. Example: 'vc_extend_my_class'
			'category'         => __( 'Creatopus', 'airpro' ),
			'admin_enqueue_js' => array( plugins_url( 'assets/admin-theme-icon.js', __FILE__ ) ),
			// This will load js file in the VC backend editor
			//'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
			'params'           => array(
				array(
					'type'        => 'iconpicker',
					'param_name'  => 'theme_icon',
					'heading'     => __( 'Icon', 'airpro' ),
					'value'       => '', // default value to backend editor admin_label
					'class'       => 'scp-theme-icon-name',
					'holder'      => 'div',
					'settings'    => array(
						'emptyIcon'    => false,
						'type'         => 'theme-icons',
						// default true, display an "EMPTY" icon?
						'iconsPerPage' => 4000,
						// default 100, how many icons per/page to display, we use (big number) to display all icons in single page
					),
					'description' => __( 'Select icon from library.', 'airpro' ),
				),
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Font Size', 'airpro' ),
					'param_name'  => 'icon_font_size',
					'description' => __( 'Value in px. Enter number only.', 'airpro' ),
				),
				array(
					'type'       => 'checkbox',
					'heading'    => __( 'Position Absolute?', 'airpro' ),
					'param_name' => 'position_absolute',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Icon alignment', 'js_composer' ),
					'param_name'  => 'alignment',
					'value'       => array(
						__( 'Left', 'js_composer' )   => 'left',
						__( 'Right', 'js_composer' )  => 'right',
						__( 'Center', 'js_composer' ) => 'center',
					),
					'description' => __( 'Select alignment.', 'js_composer' ),
				),
				array(
					'type'        => 'vc_link',
					'heading'     => __( 'URL (Link)', 'js_composer' ),
					'param_name'  => 'link',
					'description' => __( 'Add link to icon.', 'js_composer' ),
				),
				array(
					'type'       => 'dropdown',
					'class'      => '',
					'heading'    => __( 'Use Border?', 'airpro' ),
					'param_name' => 'use_border',
					'value'      => array(
						'No'  => '0',
						'Yes' => '1',
					),
				),
				array(
					'type'       => 'colorpicker',
					'heading'    => __( 'Border Color', 'airpro' ),
					'param_name' => 'border_color',
					'dependency' => array( 'element' => 'use_border', 'value' => array( '1' ) ),
				),
				array(
					'type'        => 'colorpicker',
					'heading'     => __( 'Icon Color', 'airpro' ),
					'param_name'  => 'color',
					'description' => __( 'If color is not set, theme accent color will be used.', 'airpro' ),
				),
				array(
					'type'       => 'checkbox',
					'heading'    => __( 'Use Theme Accent Color for Hover', 'airpro' ),
					'param_name' => 'hover_accent_color',
				),
				array(
					'type'        => 'colorpicker',
					'heading'     => __( 'Icon Hover Color', 'airpro' ),
					'param_name'  => 'hover_color',
					'description' => __( 'Will not be used if Use Accent Color is checked.', 'airpro' ),
				),
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Border Radius', 'airpro' ),
					'param_name'  => 'border_radius',
					'description' => __( 'Value in px. Enter number only.', 'airpro' ),
					'dependency'  => array( 'element' => 'use_border', 'value' => array( '1' ) ),
				),
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Padding', 'airpro' ),
					'param_name'  => 'icon_padding',
					'description' => __( 'Value in px. Enter number only.', 'airpro' ),
					'dependency'  => array( 'element' => 'use_border', 'value' => array( '1' ) ),
				),
				array(
					'type'        => 'textfield',
					'param_name'  => 'el_class',
					'heading'     => __( 'Extra class name', 'airpro' ),
					'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'airpro' ),
				),
				array(
					'type'       => 'css_editor',
					'heading'    => __( 'CSS box', 'js_composer' ),
					'param_name' => 'css',
					'group'      => __( 'Design Options', 'js_composer' ),
				),
			)
		) );
	}


	/*
	Shortcode logic how it should be rendered
	*/
	public function render( $atts, $content = null ) {

		extract( shortcode_atts( array(
			'theme_icon'         => '',
			'icon_font_size'     => '',
			'position_absolute'  => '',
			'link'               => '',
			'alignment'          => 'left',
			'use_border'         => '',
			'color'              => '',
			'hover_color'        => '',
			'hover_accent_color' => '',
			'border_color'       => '',
			'border_radius'      => '',
			'icon_padding'            => '10',
			'css'                => '',
			'el_class'           => '',
		), $atts ) );
		// $content = wpb_js_remove_wpautop($content); // fix unclosed/unwanted paragraph tags in $content

		$class_to_filter = 'wh-theme-icon';
		$class_to_filter .= vc_shortcode_custom_css_class( $css, ' ' );
		$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter . ' ' . $el_class, $this->namespace, $atts );

		$link     = vc_build_link( $link );
		$a_href   = $link['url'];
		$a_title  = $link['title'];
		$a_target = $link['target'];

		if ( $hover_accent_color == 'true' && function_exists( 'airpro_get_option' ) ) {
			$theme_accent_color = airpro_get_option( 'global-accent-color' );
			if ( $theme_accent_color ) {
				$hover_color = $theme_accent_color;
			}
		}

		$icon_style = '';

		if ( $icon_font_size ) {
			$icon_style .= 'font-size:' . (int) $icon_font_size . 'px;';
		}

		if ( $position_absolute == 'true' ) {
			$icon_style .= 'position:absolute;';
		}

		$hover = '';
		$wrapper_hover = '';



		if ( $hover_color ) {

			if ($use_border) {

				$wrapper_hover = 'onMouseOver="this.style.backgroundColor=\'' . $hover_color . '\';"';
				$wrapper_hover .= ' onMouseOut="this.style.backgroundColor=\'\'"';

//				$hover = 'onMouseOver="this.style.color=\'#fff\'"';
//				$hover .= ' onMouseOut="this.style.color=\'' . $color . '\'"';

			} else {


				$hover = 'onMouseOver="this.style.color=\'' . $hover_color . '\'"';
				$hover .= ' onMouseOut="this.style.color=\'' . $color . '\'"';
			}

		}

		if ( $color ) {
			$icon_style .= 'color:' . $color . '!important;';
		}

		if ( $alignment ) {
			if ( $alignment != 'left' ) {
				$icon_style .= 'text-align:' . $alignment . ';';
			}
		}

		if ( $use_border && $border_color ) {
			$icon_style .= 'border:1px solid ' . $border_color . ';';
			$icon_padding = (int) $icon_padding;
			if ( $icon_padding ) {
				$icon_style .= 'padding:' . $icon_padding . 'px;';
			}

			$border_radius = (int) $border_radius;
			if ($border_radius) {
				$icon_style .= 'border-radius:' . $border_radius . 'px;';
			}

		}

		if ( $icon_style ) {
			$icon_style = 'style="' . $icon_style . '"';
		}

		ob_start();
		?>

		<?php if ( $a_href ) : ?>
			<a
				href="<?php echo esc_attr( $a_href ); ?>"
				class="<?php echo esc_attr( trim( $css_class ) ); ?>"
				<?php if ( $a_title ) : ?>
					title="<?php echo esc_attr( $a_title ); ?>"
				<?php endif; ?>
				<?php if ( $a_target ) : ?>
					target="<?php echo esc_attr( $a_target ); ?>"
				<?php endif; ?>
				<?php echo $icon_style; ?> <?php echo $wrapper_hover; ?>
				><i class="<?php echo $theme_icon; ?>" <?php echo $hover; ?>></i></a>
		<?php else: ?>
			<div class="<?php echo esc_attr( $css_class ); ?>" <?php echo $icon_style; ?>  <?php echo $wrapper_hover; ?>>
				<i class="<?php echo $theme_icon; ?>" <?php echo $hover; ?>></i>
			</div>
		<?php endif; ?>

		<?php
		$content = ob_get_clean();

		return $content;
	}

	/*
	Load plugin css and javascript files which you may need on front end of your site
	*/
	public function loadCssAndJs() {


		wp_register_style( 'theme-icons', get_template_directory_uri() . '/assets/css/theme-icons.css', false );

		wp_enqueue_style( 'theme-icons' );
	}

	/*
	Show notice if your plugin is activated but Visual Composer is not
	*/
	public function showVcVersionNotice() {
		$plugin_data = get_plugin_data( __FILE__ );
		echo '
        <div class="updated">
          <p>' . sprintf( __( '<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'airpro' ), $plugin_data['Name'] ) . '</p>
        </div>';
	}

	function theme_icons( $icons ) {

		return array_merge( $icons, scp_get_theme_icon_list() );
	}
}

// Finally initialize code
new Scp_Theme_Icon();
